==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiGui/QDragMoveEvent_shell.h <==
#ifndef QDRAGMOVEEVENT_SHELL_H
#define QDRAGMOVEEVENT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtGui/qevent.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QVariant>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmimedata.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qrect.h>
#include <QtJambi/RegistryAPI>


class QDragMoveEvent_shell : public QDragMoveEvent, public QtJambiShellInterface
{
public:
    QDragMoveEvent_shell(const QDragMoveEvent& arg__1);
    QDragMoveEvent_shell(const QPoint& pos0, Qt::DropActions actions1, const QMimeData* data2, Qt::MouseButtons buttons3, Qt::KeyboardModifiers modifiers4, QEvent::Type type5 = QEvent::DragMove);
    ~QDragMoveEvent_shell() override;

    QDragMoveEvent* clone() const override;
    void setAccepted(bool accepted0) override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QDragMoveEvent_access : public QDragMoveEvent
{
    void __qt_assign_cref_QDragMoveEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0);
    jobject __qt_clone(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void setRect_cref_QRect(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID rect0);
    jobject rect(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QDRAGMOVEEVENT_SHELL_H

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiGui/QDragMoveEvent_shell.h <==
#ifndef QDRAGMOVEEVENT_SHELL_H
#define QDRAGMOVEEVENT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtGui/qevent.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QVariant>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmimedata.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qrect.h>
#include <QtJambi/RegistryAPI>


class QDragMoveEvent_shell : public QDragMoveEvent, public QtJambiShellInterface
{
public:
    QDragMoveEvent_shell(const QDragMoveEvent& arg__1);
    QDragMoveEvent_shell(const QPoint& pos0, Qt::DropActions actions1, const QMimeData* data2, Qt::MouseButtons buttons3, Qt::KeyboardModifiers modifiers4, QEvent::Type type5 = QEvent::DragMove);
    ~QDragMoveEvent_shell() override;

    QDragMoveEvent* clone() const override;
    void setAccepted(bool accepted0) override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QDragMoveEvent_access : public QDragMoveEvent
{
    void __qt_assign_cref_QDragMoveEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0);
    jobject __qt_clone_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void setRect_cref_QRect(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID rect0);
    jobject rect(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QDRAGMOVEEVENT_SHELL_H
